
.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. mdinclude:: ../../README.md

Base Modules
============

.. py:currentmodule:: flowws_keras_experimental

.. autoclass:: InitializeTF

.. autoclass:: Classifier

.. autoclass:: MLP

.. autoclass:: Tensorboard

.. autoclass:: Train

.. autoclass:: Save

Image-Related Tasks
===================

.. py:currentmodule:: flowws_keras_experimental.images

Data sources
------------

.. autoclass:: CIFAR100

.. autoclass:: CIFAR10

.. autoclass:: ImagenetDirectory

.. autoclass:: MNIST

Architectures
-------------

.. autoclass:: Encoder

.. autoclass:: MobileNetV2

.. autoclass:: ResNet

==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
